@@ -413,7 +413,11 @@ static void mailparse_mimemessage_extract(int flags, INTERNAL_FUNCTION_PARAMETER
 
 
 	if (part->source.kind == mpSTRING)
+#if PHP_VERSION_ID < 80100
 		srcstream = php_stream_memory_open(TEMP_STREAM_READONLY, Z_STRVAL_P(&part->source.zval), Z_STRLEN_P(&part->source.zval));
+#else
+		srcstream = php_stream_memory_open(TEMP_STREAM_READONLY, Z_STR(part->source.zval));
+#endif
 	else
 		php_stream_from_zval(srcstream, &part->source.zval);
 
@@ -430,11 +434,15 @@ static void mailparse_mimemessage_extract(int flags, INTERNAL_FUNCTION_PARAMETER
 	if (SUCCESS == extract_part(part, flags, srcstream, callback_data, callback)) {
 
 		if (mode == MAILPARSE_EXTRACT_RETURN) {
+#if PHP_VERSION_ID < 80100
 			size_t len;
 			char *buf;
 
 			buf = php_stream_memory_get_buffer(deststream, &len);
 			RETVAL_STRINGL(buf, len);
+#else
+			RETVAL_STR_COPY(php_stream_memory_get_buffer(deststream));
+#endif
 		} else {
 			RETVAL_TRUE;
 		}
@@ -502,7 +510,11 @@ PHP_METHOD(mimemessage, extract_uue)
 	}
 
 	if (part->source.kind == mpSTRING)
+#if PHP_VERSION_ID < 80100
 		srcstream = php_stream_memory_open(TEMP_STREAM_READONLY, Z_STRVAL_P(&part->source.zval), Z_STRLEN_P(&part->source.zval));
+#else
+		srcstream = php_stream_memory_open(TEMP_STREAM_READONLY, Z_STR(part->source.zval));
+#endif
 	else
 		php_stream_from_zval(srcstream, &part->source.zval);
 
@@ -535,11 +547,15 @@ PHP_METHOD(mimemessage, extract_uue)
 			if (nparts == index) {
 				mailparse_do_uudecode(srcstream, deststream);
 				if (mode == MAILPARSE_EXTRACT_RETURN) {
+#if PHP_VERSION_ID < 80100
 					size_t len;
 					char *buf;
 
 					buf = php_stream_memory_get_buffer(deststream, &len);
 					RETVAL_STRINGL(buf, len);
+#else
+					RETVAL_STR_COPY(php_stream_memory_get_buffer(deststream));
+#endif
 				} else {
 					RETVAL_TRUE;
 				}
@@ -584,7 +600,11 @@ PHP_METHOD(mimemessage, enum_uue)
 		return;
 
 	if (part->source.kind == mpSTRING)
+#if PHP_VERSION_ID < 80100
 		instream = php_stream_memory_open(TEMP_STREAM_READONLY, Z_STRVAL_P(&part->source.zval), Z_STRLEN_P(&part->source.zval));
+#else
+		instream = php_stream_memory_open(TEMP_STREAM_READONLY, Z_STR(part->source.zval));
+#endif
 	else
 		php_stream_from_zval(instream, &part->source.zval);
 
@@ -683,13 +703,17 @@ static size_t mailparse_do_uudecode(php_stream *instream, php_stream *outstream)
 	int x, A, B, C, D, n;
 	size_t file_size = 0;
 	char line[128];
+	int backtick_line = 0;
 
 	if (outstream) {
 		/* write to outstream */
 		while(!php_stream_eof(instream))	{
-			if (!php_stream_gets(instream, line, sizeof(line))) {
+			if (!php_stream_gets(instream, line, sizeof(line))
+				|| (backtick_line && strncmp(line, "end", 3) == 0 && (line[3] == '\r' || line[3] == '\n'))
+			) {
 				break;
 			}
+			backtick_line = line[0] == '`' && (line[1] == '\r' || line[1] == '\n');
 			x = 0;
 
 			UU_NEXT(n);
@@ -811,13 +835,13 @@ PHP_FUNCTION(mailparse_uudecode_all)
 				array_init(&item);
 				add_assoc_string(&item, "filename", ZSTR_VAL(outpath));
 				add_next_index_zval(return_value, &item);
+				zend_string_release(outpath);
 			}
 
 			/* add an item */
 			array_init(&item);
 			add_assoc_string(&item, "origfilename", origfilename);
 
-			zend_string_release(outpath);
 			/* create a temp file for the data */
 			partstream = _mailparse_create_stream(&outpath);
 			if (partstream)	{
@@ -828,8 +852,8 @@ PHP_FUNCTION(mailparse_uudecode_all)
 				/* decode it */
 				mailparse_do_uudecode(instream, partstream);
 				php_stream_close(partstream);
+				zend_string_release(outpath);
 			}
-			zend_string_release(outpath);
 		} else {
 			/* write to the output file */
 			php_stream_write_string(outstream, buffer);
@@ -1183,16 +1207,25 @@ PHP_FUNCTION(mailparse_msg_get_structure)
 static int extract_callback_user_func(php_mimepart *part, zval *userfunc, const char *p, size_t n)
 {
 	zval retval, arg;
-
-	ZVAL_FALSE(&retval);
+	zend_fcall_info fci;
+	zend_fcall_info_cache fcc;
 
 	ZVAL_STRINGL(&arg, (char*)p, (int)n);
 
-	/* TODO: use zend_is_callable */
-
-	if (call_user_function(EG(function_table), NULL, userfunc, &retval, 1, &arg) == FAILURE)
+	if (zend_fcall_info_init(userfunc, 0, &fci, &fcc, NULL, NULL) == FAILURE) {
 		zend_error(E_WARNING, "%s(): unable to call user function", get_active_function_name());
+		return 0;
+	}
 
+	zend_fcall_info_argn(&fci, 1, &arg);
+	fci.retval = &retval;
+	if (zend_call_function(&fci, &fcc)) {
+		zend_fcall_info_args_clear(&fci, 1);
+		zend_error(E_WARNING, "%s(): unable to call user function", get_active_function_name());
+		return 0;
+	}
+
+	zend_fcall_info_args_clear(&fci, 1);
 	zval_ptr_dtor(&retval);
 	zval_ptr_dtor(&arg);
 
@@ -1299,7 +1332,11 @@ static void mailparse_do_extract(INTERNAL_FUNCTION_PARAMETERS, int decode, int i
 		close_src_stream = 1;
 	} else {
 		/* filename is the actual data */
+#if PHP_VERSION_ID < 80100
 		srcstream = php_stream_memory_open(TEMP_STREAM_READONLY, Z_STRVAL_P(filename), Z_STRLEN_P(filename));
+#else
+		srcstream = php_stream_memory_open(TEMP_STREAM_READONLY, Z_STR_P(filename));
+#endif
 		close_src_stream = 1;
 	}
 
@@ -1317,8 +1354,6 @@ static void mailparse_do_extract(INTERNAL_FUNCTION_PARAMETERS, int decode, int i
 			cbdata = deststream;
 			deststream = NULL; /* don't free this one */
 		} else {
-			if (Z_TYPE_P(callbackfunc) != IS_ARRAY)
-				convert_to_string_ex(callbackfunc);
 			cbfunc = (php_mimepart_extract_func_t)&extract_callback_user_func;
 			cbdata = callbackfunc;
 		}
@@ -1332,12 +1367,15 @@ static void mailparse_do_extract(INTERNAL_FUNCTION_PARAMETERS, int decode, int i
 	if (SUCCESS == extract_part(part, decode, srcstream, cbdata, cbfunc)) {
 
 		if (deststream != NULL) {
+#if PHP_VERSION_ID < 80100
 			/* return it's contents as a string */
 			char *membuf = NULL;
 			size_t memlen = 0;
 			membuf = php_stream_memory_get_buffer(deststream, &memlen);
 			RETVAL_STRINGL(membuf, memlen);
-
+#else
+			RETVAL_STR_COPY(php_stream_memory_get_buffer(deststream));
+#endif
 		} else {
 			RETVAL_TRUE;
 		}
