@@ -1,13 +1,11 @@
 /*
    +----------------------------------------------------------------------+
-   | PHP Version 4                                                        |
+   | Copyright (c) The PHP Group                                          |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2004 The PHP Group                                |
-   +----------------------------------------------------------------------+
-   | This source file is subject to version 2.02 of the PHP license,      |
+   | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
    | available at through the world-wide-web at                           |
-   | http://www.php.net/license/2_02.txt.                                 |
+   | http://www.php.net/license/3_01.txt.                                 |
    | If you did not receive a copy of the PHP license and are unable to   |
    | obtain it through the world-wide-web, please send a note to          |
    | license@php.net so we can mail you a copy immediately.               |
@@ -17,7 +15,6 @@
    | the support routines for this extension were based upon.             |
    +----------------------------------------------------------------------+
  */
-/* $Id: php_mailparse.h 276739 2009-03-03 23:09:08Z shire $ */
 
 #ifndef PHP_MAILPARSE_H
 #define PHP_MAILPARSE_H
@@ -25,7 +22,7 @@
 extern zend_module_entry mailparse_module_entry;
 #define phpext_mailparse_ptr &mailparse_module_entry
 
-#define PHP_MAILPARSE_VERSION "2.1.6"
+#define PHP_MAILPARSE_VERSION "3.1.3"
 
 #ifdef PHP_WIN32
 #define PHP_MAILPARSE_API __declspec(dllexport)
@@ -33,18 +30,6 @@ extern zend_module_entry mailparse_module_entry;
 #define PHP_MAILPARSE_API
 #endif
 
-#ifndef  Z_SET_REFCOUNT_P
-# if PHP_MAJOR_VERSION < 6 && (PHP_MAJOR_VERSION == 5 && PHP_MINOR_VERSION < 3)
-#  define Z_SET_REFCOUNT_P(pz, rc)  (pz)->refcount = rc 
-#  define Z_UNSET_ISREF_P(pz) (pz)->is_ref = 0 
-#  define Z_DELREF_P(pz) (pz)->refcount--
-#  define Z_REFCOUNT_P(pz) (pz)->refcount
-#  define Z_ISREF_P(pz) (pz)->is_ref
-#  define Z_ADDREF_P(pz) (pz)->refcount++
-#  define Z_SET_ISREF_TO_P(pz, isref) (pz)->is_ref = isref
-# endif
-#endif
-
 PHP_MINIT_FUNCTION(mailparse);
 PHP_MSHUTDOWN_FUNCTION(mailparse);
 PHP_RINIT_FUNCTION(mailparse);
@@ -77,33 +62,21 @@ PHP_FUNCTION(mailparse_uudecode_all);
 PHP_FUNCTION(mailparse_test);
 
 PHP_MAILPARSE_API int php_mailparse_le_mime_part(void);
+PHP_MAILPARSE_API char* php_mailparse_msg_name(void);
 
 /* mimemessage object */
-PHP_FUNCTION(mailparse_mimemessage);
-PHP_FUNCTION(mailparse_mimemessage_get_parent);
-PHP_FUNCTION(mailparse_mimemessage_get_child);
-PHP_FUNCTION(mailparse_mimemessage_get_child_count);
-PHP_FUNCTION(mailparse_mimemessage_extract_headers);
-PHP_FUNCTION(mailparse_mimemessage_extract_body);
-PHP_FUNCTION(mailparse_mimemessage_enum_uue);
-PHP_FUNCTION(mailparse_mimemessage_extract_uue);
-PHP_FUNCTION(mailparse_mimemessage_remove);
-PHP_FUNCTION(mailparse_mimemessage_add_child);
+PHP_METHOD(mimemessage, __construct);
+PHP_METHOD(mimemessage, get_child);
+PHP_METHOD(mimemessage, get_child_count);
+PHP_METHOD(mimemessage, get_parent);
+PHP_METHOD(mimemessage, extract_headers);
+PHP_METHOD(mimemessage, extract_body);
+PHP_METHOD(mimemessage, enum_uue);
+PHP_METHOD(mimemessage, extract_uue);
+PHP_METHOD(mimemessage, remove);
+PHP_METHOD(mimemessage, add_child);
 
-/* PHP 4.3.4  moved the mbfilter header around */
-#if PHP_MAJOR_VERSION == 4 && ((PHP_MINOR_VERSION < 3) || (PHP_MINOR_VERSION == 3 && PHP_RELEASE_VERSION < 4))
-# include "ext/mbstring/mbfilter.h"
-# define MAILPARSE_MBSTRING_TSRMLS_CC	TSRMLS_CC
-# define MAILPARSE_MBSTRING_TSRMLS_DC	TSRMLS_DC
-# define MAILPARSE_MBSTRING_TSRMLS_FETCH_IF_BRAIN_DEAD()	/* sanity */
-#else
 # include "ext/mbstring/libmbfl/mbfl/mbfilter.h"
-/* ugh, even worse, they changed the signature of the API and made it
- * really slow for threaded PHP builds */
-# define MAILPARSE_MBSTRING_TSRMLS_CC	/* pain */
-# define MAILPARSE_MBSTRING_TSRMLS_DC	/* pain */
-# define MAILPARSE_MBSTRING_TSRMLS_FETCH_IF_BRAIN_DEAD()	TSRMLS_FETCH()
-#endif
 
 #include "php_mailparse_rfc822.h"
 #include "php_mailparse_mime.h"
